@@ -1,6 +1,11 @@
 """
-`xr` is the top level module of the pyopenxr unofficial python bindings for the
-OpenXR SDK to access VR and AR devices.
+`xr` is the root module of pyopenxr, an unofficial Python binding for the OpenXR SDK.
+
+It provides low-level access to the core OpenXR API for interacting with VR and AR runtimes,
+including system queries, session management, and extension dispatch. This module wraps the
+standard C interface in a Pythonic structure while preserving fidelity to the original spec.
+
+For high-level utilities and ergonomic abstractions, see submodules and helper packages.
 """
 
 from . import (
@@ -9,14 +14,10 @@ from . import (
     enums,
     typedefs,
     functions,
+    custom_functions,
     platform,
     exception,
-    classes,
     api_layer,
-    context_object,
-    opengl_graphics,
-    matrix4x4f,
-    extension,
 )
 
 from .version import *
@@ -24,19 +25,13 @@ from .constants import *
 from .enums import *
 from .typedefs import *
 from .functions import *
+from .custom_functions import *
 from .platform import *
 from .exception import *
-from .classes import *
 from .api_layer import *
-from .context_object import *
-from .opengl_graphics import *
-from .matrix4x4f import *
 
 
-# from .experiment import *
-
 __all__ = [
-    "extension",
 ]
 
 for subpackage in (
@@ -45,17 +40,10 @@ for subpackage in (
     enums,
     typedefs,
     functions,
+    custom_functions,
     platform,
-    exception,
-    classes,
     api_layer,
-    context_object,
-    opengl_graphics,
-    matrix4x4f,
 ):
     __all__ += subpackage.__all__
 
-from .api_layer.steamvr_linux_destroyinstance_layer import SteamVrLinuxDestroyInstanceLayer
-__all__ += "SteamVrLinuxDestroyInstanceLayer"
-
 __version__ = version.PYOPENXR_VERSION  # Not in __all__, right?
