@@ -347,12 +347,12 @@ class InstanceLostError(ErrorResult):
 
 
 class SessionRunningError(ErrorResult):
-    """The session <<session_running, is already running>>."""
+    """The session <<session-running, is already running>>."""
 
     def __init__(self, message=None):
         if message is None:
             super().__init__(
-                "The session <<session_running, is already running>>."
+                "The session <<session-running, is already running>>."
             )
         else:
             super().__init__(message)
@@ -363,12 +363,12 @@ class SessionRunningError(ErrorResult):
 
 
 class SessionNotRunningError(ErrorResult):
-    """The session <<session_not_running, is not yet running>>."""
+    """The session <<session-not-running, is not yet running>>."""
 
     def __init__(self, message=None):
         if message is None:
             super().__init__(
-                "The session <<session_not_running, is not yet running>>."
+                "The session <<session-not-running, is not yet running>>."
             )
         else:
             super().__init__(message)
@@ -922,6 +922,18 @@ class RuntimeUnavailableError(ErrorResult):
         return Result.ERROR_RUNTIME_UNAVAILABLE
 
 
+class ExtensionDependencyNotEnabledError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_EXTENSION_DEPENDENCY_NOT_ENABLED
+
+
+class PermissionInsufficientError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_PERMISSION_INSUFFICIENT
+
+
 class AndroidThreadSettingsIdInvalidKHRError(ErrorResult):
     @staticmethod
     def get_result_enum() -> Result:
@@ -1090,6 +1102,108 @@ class MarkerIdInvalidVarjoError(ErrorResult):
         return Result.ERROR_MARKER_ID_INVALID_VARJO
 
 
+class MarkerDetectorPermissionDeniedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_MARKER_DETECTOR_PERMISSION_DENIED_ML
+
+
+class MarkerDetectorLocateFailedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_MARKER_DETECTOR_LOCATE_FAILED_ML
+
+
+class MarkerDetectorInvalidDataQueryMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_MARKER_DETECTOR_INVALID_DATA_QUERY_ML
+
+
+class MarkerDetectorInvalidCreateInfoMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_MARKER_DETECTOR_INVALID_CREATE_INFO_ML
+
+
+class MarkerInvalidMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_MARKER_INVALID_ML
+
+
+class LocalizationMapIncompatibleMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_LOCALIZATION_MAP_INCOMPATIBLE_ML
+
+
+class LocalizationMapUnavailableMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_LOCALIZATION_MAP_UNAVAILABLE_ML
+
+
+class LocalizationMapFailMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_LOCALIZATION_MAP_FAIL_ML
+
+
+class LocalizationMapImportExportPermissionDeniedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_LOCALIZATION_MAP_IMPORT_EXPORT_PERMISSION_DENIED_ML
+
+
+class LocalizationMapPermissionDeniedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_LOCALIZATION_MAP_PERMISSION_DENIED_ML
+
+
+class LocalizationMapAlreadyExistsMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_LOCALIZATION_MAP_ALREADY_EXISTS_ML
+
+
+class LocalizationMapCannotExportCloudMapMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_LOCALIZATION_MAP_CANNOT_EXPORT_CLOUD_MAP_ML
+
+
+class SpatialAnchorsPermissionDeniedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHORS_PERMISSION_DENIED_ML
+
+
+class SpatialAnchorsNotLocalizedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHORS_NOT_LOCALIZED_ML
+
+
+class SpatialAnchorsOutOfMapBoundsMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHORS_OUT_OF_MAP_BOUNDS_ML
+
+
+class SpatialAnchorsSpaceNotLocatableMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHORS_SPACE_NOT_LOCATABLE_ML
+
+
+class SpatialAnchorsAnchorNotFoundMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHORS_ANCHOR_NOT_FOUND_ML
+
+
 class SpatialAnchorNameNotFoundMSFTError(ErrorResult):
     @staticmethod
     def get_result_enum() -> Result:
@@ -1102,6 +1216,378 @@ class SpatialAnchorNameInvalidMSFTError(ErrorResult):
         return Result.ERROR_SPATIAL_ANCHOR_NAME_INVALID_MSFT
 
 
+class SceneMarkerDataNotStringMSFT(QualifiedSuccessResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.SCENE_MARKER_DATA_NOT_STRING_MSFT
+
+
+class SpaceMappingInsufficientFBError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_MAPPING_INSUFFICIENT_FB
+
+
+class SpaceLocalizationFailedFBError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_LOCALIZATION_FAILED_FB
+
+
+class SpaceNetworkTimeoutFBError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_NETWORK_TIMEOUT_FB
+
+
+class SpaceNetworkRequestFailedFBError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_NETWORK_REQUEST_FAILED_FB
+
+
+class SpaceCloudStorageDisabledFBError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_CLOUD_STORAGE_DISABLED_FB
+
+
+class SpaceInsufficientResourcesMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_INSUFFICIENT_RESOURCES_META
+
+
+class SpaceStorageAtCapacityMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_STORAGE_AT_CAPACITY_META
+
+
+class SpaceInsufficientViewMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_INSUFFICIENT_VIEW_META
+
+
+class SpacePermissionInsufficientMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_PERMISSION_INSUFFICIENT_META
+
+
+class SpaceRateLimitedMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_RATE_LIMITED_META
+
+
+class SpaceTooDarkMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_TOO_DARK_META
+
+
+class SpaceTooBrightMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_TOO_BRIGHT_META
+
+
+class PassthroughColorLutBufferSizeMismatchMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_PASSTHROUGH_COLOR_LUT_BUFFER_SIZE_MISMATCH_META
+
+
+class EnvironmentDepthNotAvailableMETA(QualifiedSuccessResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ENVIRONMENT_DEPTH_NOT_AVAILABLE_META
+
+
+class RenderModelIdInvalidEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_RENDER_MODEL_ID_INVALID_EXT
+
+
+class RenderModelAssetUnavailableEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_RENDER_MODEL_ASSET_UNAVAILABLE_EXT
+
+
+class RenderModelGltfExtensionRequiredEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_RENDER_MODEL_GLTF_EXTENSION_REQUIRED_EXT
+
+
+class NotInteractionRenderModelEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_NOT_INTERACTION_RENDER_MODEL_EXT
+
+
+class HintAlreadySetQCOMError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_HINT_ALREADY_SET_QCOM
+
+
+class NotAnAnchorHTCError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_NOT_AN_ANCHOR_HTC
+
+
+class SpatialEntityIdInvalidBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ENTITY_ID_INVALID_BD
+
+
+class SpatialSensingServiceUnavailableBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_SENSING_SERVICE_UNAVAILABLE_BD
+
+
+class AnchorNotSupportedForEntityBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_ANCHOR_NOT_SUPPORTED_FOR_ENTITY_BD
+
+
+class SpatialAnchorNotFoundBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHOR_NOT_FOUND_BD
+
+
+class SpatialAnchorSharingNetworkTimeoutBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHOR_SHARING_NETWORK_TIMEOUT_BD
+
+
+class SpatialAnchorSharingAuthenticationFailureBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHOR_SHARING_AUTHENTICATION_FAILURE_BD
+
+
+class SpatialAnchorSharingNetworkFailureBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHOR_SHARING_NETWORK_FAILURE_BD
+
+
+class SpatialAnchorSharingLocalizationFailBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHOR_SHARING_LOCALIZATION_FAIL_BD
+
+
+class SpatialAnchorSharingMapInsufficientBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ANCHOR_SHARING_MAP_INSUFFICIENT_BD
+
+
+class SceneCaptureFailureBDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SCENE_CAPTURE_FAILURE_BD
+
+
+class SpaceNotLocatableEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_NOT_LOCATABLE_EXT
+
+
+class PlaneDetectionPermissionDeniedEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_PLANE_DETECTION_PERMISSION_DENIED_EXT
+
+
+class MismatchingTrackableTypeANDROIDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_MISMATCHING_TRACKABLE_TYPE_ANDROID
+
+
+class TrackableTypeNotSupportedANDROIDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_TRACKABLE_TYPE_NOT_SUPPORTED_ANDROID
+
+
+class AnchorIdNotFoundANDROIDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_ANCHOR_ID_NOT_FOUND_ANDROID
+
+
+class AnchorAlreadyPersistedANDROIDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_ANCHOR_ALREADY_PERSISTED_ANDROID
+
+
+class AnchorNotTrackingANDROIDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_ANCHOR_NOT_TRACKING_ANDROID
+
+
+class PersistedDataNotReadyANDROIDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_PERSISTED_DATA_NOT_READY_ANDROID
+
+
+class FuturePendingEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_FUTURE_PENDING_EXT
+
+
+class FutureInvalidEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_FUTURE_INVALID_EXT
+
+
+class SystemNotificationPermissionDeniedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SYSTEM_NOTIFICATION_PERMISSION_DENIED_ML
+
+
+class SystemNotificationIncompatibleSkuMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SYSTEM_NOTIFICATION_INCOMPATIBLE_SKU_ML
+
+
+class WorldMeshDetectorPermissionDeniedMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_WORLD_MESH_DETECTOR_PERMISSION_DENIED_ML
+
+
+class WorldMeshDetectorSpaceNotLocatableMLError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_WORLD_MESH_DETECTOR_SPACE_NOT_LOCATABLE_ML
+
+
+class FacialExpressionPermissionDeniedMLError(QualifiedSuccessResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_FACIAL_EXPRESSION_PERMISSION_DENIED_ML
+
+
+class ColocationDiscoveryNetworkFailedMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_COLOCATION_DISCOVERY_NETWORK_FAILED_META
+
+
+class ColocationDiscoveryNoDiscoveryMethodMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_COLOCATION_DISCOVERY_NO_DISCOVERY_METHOD_META
+
+
+class ColocationDiscoveryAlreadyAdvertisingMETA(QualifiedSuccessResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.COLOCATION_DISCOVERY_ALREADY_ADVERTISING_META
+
+
+class ColocationDiscoveryAlreadyDiscoveringMETA(QualifiedSuccessResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.COLOCATION_DISCOVERY_ALREADY_DISCOVERING_META
+
+
+class SpaceGroupNotFoundMETAError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPACE_GROUP_NOT_FOUND_META
+
+
+class AnchorNotOwnedByCallerANDROIDError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_ANCHOR_NOT_OWNED_BY_CALLER_ANDROID
+
+
+class SpatialCapabilityUnsupportedEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_CAPABILITY_UNSUPPORTED_EXT
+
+
+class SpatialEntityIdInvalidEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_ENTITY_ID_INVALID_EXT
+
+
+class SpatialBufferIdInvalidEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_BUFFER_ID_INVALID_EXT
+
+
+class SpatialComponentUnsupportedForCapabilityEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_COMPONENT_UNSUPPORTED_FOR_CAPABILITY_EXT
+
+
+class SpatialCapabilityConfigurationInvalidEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_CAPABILITY_CONFIGURATION_INVALID_EXT
+
+
+class SpatialComponentNotEnabledEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_COMPONENT_NOT_ENABLED_EXT
+
+
+class SpatialPersistenceScopeUnsupportedEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_PERSISTENCE_SCOPE_UNSUPPORTED_EXT
+
+
+class SpatialPersistenceScopeIncompatibleEXTError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_SPATIAL_PERSISTENCE_SCOPE_INCOMPATIBLE_EXT
+
+
+class ExtensionDependencyNotEnabledKHRError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_EXTENSION_DEPENDENCY_NOT_ENABLED_KHR
+
+
+class PermissionInsufficientKHRError(ErrorResult):
+    @staticmethod
+    def get_result_enum() -> Result:
+        return Result.ERROR_PERMISSION_INSUFFICIENT_KHR
+
+
 _exception_map = {
     Result.SUCCESS: Success,
     Result.TIMEOUT_EXPIRED: TimeoutExpired,
@@ -1158,6 +1644,8 @@ _exception_map = {
     Result.ERROR_LOCALIZED_NAME_INVALID: LocalizedNameInvalidError,
     Result.ERROR_GRAPHICS_REQUIREMENTS_CALL_MISSING: GraphicsRequirementsCallMissingError,
     Result.ERROR_RUNTIME_UNAVAILABLE: RuntimeUnavailableError,
+    Result.ERROR_EXTENSION_DEPENDENCY_NOT_ENABLED: ExtensionDependencyNotEnabledError,
+    Result.ERROR_PERMISSION_INSUFFICIENT: PermissionInsufficientError,
     Result.ERROR_ANDROID_THREAD_SETTINGS_ID_INVALID_KHR: AndroidThreadSettingsIdInvalidKHRError,
     Result.ERROR_ANDROID_THREAD_SETTINGS_FAILURE_KHR: AndroidThreadSettingsFailureKHRError,
     Result.ERROR_CREATE_SPATIAL_ANCHOR_FAILED_MSFT: CreateSpatialAnchorFailedMSFTError,
@@ -1186,8 +1674,87 @@ _exception_map = {
     Result.RENDER_MODEL_UNAVAILABLE_FB: RenderModelUnavailableFB,
     Result.ERROR_MARKER_NOT_TRACKED_VARJO: MarkerNotTrackedVarjoError,
     Result.ERROR_MARKER_ID_INVALID_VARJO: MarkerIdInvalidVarjoError,
+    Result.ERROR_MARKER_DETECTOR_PERMISSION_DENIED_ML: MarkerDetectorPermissionDeniedMLError,
+    Result.ERROR_MARKER_DETECTOR_LOCATE_FAILED_ML: MarkerDetectorLocateFailedMLError,
+    Result.ERROR_MARKER_DETECTOR_INVALID_DATA_QUERY_ML: MarkerDetectorInvalidDataQueryMLError,
+    Result.ERROR_MARKER_DETECTOR_INVALID_CREATE_INFO_ML: MarkerDetectorInvalidCreateInfoMLError,
+    Result.ERROR_MARKER_INVALID_ML: MarkerInvalidMLError,
+    Result.ERROR_LOCALIZATION_MAP_INCOMPATIBLE_ML: LocalizationMapIncompatibleMLError,
+    Result.ERROR_LOCALIZATION_MAP_UNAVAILABLE_ML: LocalizationMapUnavailableMLError,
+    Result.ERROR_LOCALIZATION_MAP_FAIL_ML: LocalizationMapFailMLError,
+    Result.ERROR_LOCALIZATION_MAP_IMPORT_EXPORT_PERMISSION_DENIED_ML: LocalizationMapImportExportPermissionDeniedMLError,
+    Result.ERROR_LOCALIZATION_MAP_PERMISSION_DENIED_ML: LocalizationMapPermissionDeniedMLError,
+    Result.ERROR_LOCALIZATION_MAP_ALREADY_EXISTS_ML: LocalizationMapAlreadyExistsMLError,
+    Result.ERROR_LOCALIZATION_MAP_CANNOT_EXPORT_CLOUD_MAP_ML: LocalizationMapCannotExportCloudMapMLError,
+    Result.ERROR_SPATIAL_ANCHORS_PERMISSION_DENIED_ML: SpatialAnchorsPermissionDeniedMLError,
+    Result.ERROR_SPATIAL_ANCHORS_NOT_LOCALIZED_ML: SpatialAnchorsNotLocalizedMLError,
+    Result.ERROR_SPATIAL_ANCHORS_OUT_OF_MAP_BOUNDS_ML: SpatialAnchorsOutOfMapBoundsMLError,
+    Result.ERROR_SPATIAL_ANCHORS_SPACE_NOT_LOCATABLE_ML: SpatialAnchorsSpaceNotLocatableMLError,
+    Result.ERROR_SPATIAL_ANCHORS_ANCHOR_NOT_FOUND_ML: SpatialAnchorsAnchorNotFoundMLError,
     Result.ERROR_SPATIAL_ANCHOR_NAME_NOT_FOUND_MSFT: SpatialAnchorNameNotFoundMSFTError,
     Result.ERROR_SPATIAL_ANCHOR_NAME_INVALID_MSFT: SpatialAnchorNameInvalidMSFTError,
+    Result.SCENE_MARKER_DATA_NOT_STRING_MSFT: SceneMarkerDataNotStringMSFT,
+    Result.ERROR_SPACE_MAPPING_INSUFFICIENT_FB: SpaceMappingInsufficientFBError,
+    Result.ERROR_SPACE_LOCALIZATION_FAILED_FB: SpaceLocalizationFailedFBError,
+    Result.ERROR_SPACE_NETWORK_TIMEOUT_FB: SpaceNetworkTimeoutFBError,
+    Result.ERROR_SPACE_NETWORK_REQUEST_FAILED_FB: SpaceNetworkRequestFailedFBError,
+    Result.ERROR_SPACE_CLOUD_STORAGE_DISABLED_FB: SpaceCloudStorageDisabledFBError,
+    Result.ERROR_SPACE_INSUFFICIENT_RESOURCES_META: SpaceInsufficientResourcesMETAError,
+    Result.ERROR_SPACE_STORAGE_AT_CAPACITY_META: SpaceStorageAtCapacityMETAError,
+    Result.ERROR_SPACE_INSUFFICIENT_VIEW_META: SpaceInsufficientViewMETAError,
+    Result.ERROR_SPACE_PERMISSION_INSUFFICIENT_META: SpacePermissionInsufficientMETAError,
+    Result.ERROR_SPACE_RATE_LIMITED_META: SpaceRateLimitedMETAError,
+    Result.ERROR_SPACE_TOO_DARK_META: SpaceTooDarkMETAError,
+    Result.ERROR_SPACE_TOO_BRIGHT_META: SpaceTooBrightMETAError,
+    Result.ERROR_PASSTHROUGH_COLOR_LUT_BUFFER_SIZE_MISMATCH_META: PassthroughColorLutBufferSizeMismatchMETAError,
+    Result.ENVIRONMENT_DEPTH_NOT_AVAILABLE_META: EnvironmentDepthNotAvailableMETA,
+    Result.ERROR_RENDER_MODEL_ID_INVALID_EXT: RenderModelIdInvalidEXTError,
+    Result.ERROR_RENDER_MODEL_ASSET_UNAVAILABLE_EXT: RenderModelAssetUnavailableEXTError,
+    Result.ERROR_RENDER_MODEL_GLTF_EXTENSION_REQUIRED_EXT: RenderModelGltfExtensionRequiredEXTError,
+    Result.ERROR_NOT_INTERACTION_RENDER_MODEL_EXT: NotInteractionRenderModelEXTError,
+    Result.ERROR_HINT_ALREADY_SET_QCOM: HintAlreadySetQCOMError,
+    Result.ERROR_NOT_AN_ANCHOR_HTC: NotAnAnchorHTCError,
+    Result.ERROR_SPATIAL_ENTITY_ID_INVALID_BD: SpatialEntityIdInvalidBDError,
+    Result.ERROR_SPATIAL_SENSING_SERVICE_UNAVAILABLE_BD: SpatialSensingServiceUnavailableBDError,
+    Result.ERROR_ANCHOR_NOT_SUPPORTED_FOR_ENTITY_BD: AnchorNotSupportedForEntityBDError,
+    Result.ERROR_SPATIAL_ANCHOR_NOT_FOUND_BD: SpatialAnchorNotFoundBDError,
+    Result.ERROR_SPATIAL_ANCHOR_SHARING_NETWORK_TIMEOUT_BD: SpatialAnchorSharingNetworkTimeoutBDError,
+    Result.ERROR_SPATIAL_ANCHOR_SHARING_AUTHENTICATION_FAILURE_BD: SpatialAnchorSharingAuthenticationFailureBDError,
+    Result.ERROR_SPATIAL_ANCHOR_SHARING_NETWORK_FAILURE_BD: SpatialAnchorSharingNetworkFailureBDError,
+    Result.ERROR_SPATIAL_ANCHOR_SHARING_LOCALIZATION_FAIL_BD: SpatialAnchorSharingLocalizationFailBDError,
+    Result.ERROR_SPATIAL_ANCHOR_SHARING_MAP_INSUFFICIENT_BD: SpatialAnchorSharingMapInsufficientBDError,
+    Result.ERROR_SCENE_CAPTURE_FAILURE_BD: SceneCaptureFailureBDError,
+    Result.ERROR_SPACE_NOT_LOCATABLE_EXT: SpaceNotLocatableEXTError,
+    Result.ERROR_PLANE_DETECTION_PERMISSION_DENIED_EXT: PlaneDetectionPermissionDeniedEXTError,
+    Result.ERROR_MISMATCHING_TRACKABLE_TYPE_ANDROID: MismatchingTrackableTypeANDROIDError,
+    Result.ERROR_TRACKABLE_TYPE_NOT_SUPPORTED_ANDROID: TrackableTypeNotSupportedANDROIDError,
+    Result.ERROR_ANCHOR_ID_NOT_FOUND_ANDROID: AnchorIdNotFoundANDROIDError,
+    Result.ERROR_ANCHOR_ALREADY_PERSISTED_ANDROID: AnchorAlreadyPersistedANDROIDError,
+    Result.ERROR_ANCHOR_NOT_TRACKING_ANDROID: AnchorNotTrackingANDROIDError,
+    Result.ERROR_PERSISTED_DATA_NOT_READY_ANDROID: PersistedDataNotReadyANDROIDError,
+    Result.ERROR_FUTURE_PENDING_EXT: FuturePendingEXTError,
+    Result.ERROR_FUTURE_INVALID_EXT: FutureInvalidEXTError,
+    Result.ERROR_SYSTEM_NOTIFICATION_PERMISSION_DENIED_ML: SystemNotificationPermissionDeniedMLError,
+    Result.ERROR_SYSTEM_NOTIFICATION_INCOMPATIBLE_SKU_ML: SystemNotificationIncompatibleSkuMLError,
+    Result.ERROR_WORLD_MESH_DETECTOR_PERMISSION_DENIED_ML: WorldMeshDetectorPermissionDeniedMLError,
+    Result.ERROR_WORLD_MESH_DETECTOR_SPACE_NOT_LOCATABLE_ML: WorldMeshDetectorSpaceNotLocatableMLError,
+    Result.ERROR_FACIAL_EXPRESSION_PERMISSION_DENIED_ML: FacialExpressionPermissionDeniedMLError,
+    Result.ERROR_COLOCATION_DISCOVERY_NETWORK_FAILED_META: ColocationDiscoveryNetworkFailedMETAError,
+    Result.ERROR_COLOCATION_DISCOVERY_NO_DISCOVERY_METHOD_META: ColocationDiscoveryNoDiscoveryMethodMETAError,
+    Result.COLOCATION_DISCOVERY_ALREADY_ADVERTISING_META: ColocationDiscoveryAlreadyAdvertisingMETA,
+    Result.COLOCATION_DISCOVERY_ALREADY_DISCOVERING_META: ColocationDiscoveryAlreadyDiscoveringMETA,
+    Result.ERROR_SPACE_GROUP_NOT_FOUND_META: SpaceGroupNotFoundMETAError,
+    Result.ERROR_ANCHOR_NOT_OWNED_BY_CALLER_ANDROID: AnchorNotOwnedByCallerANDROIDError,
+    Result.ERROR_SPATIAL_CAPABILITY_UNSUPPORTED_EXT: SpatialCapabilityUnsupportedEXTError,
+    Result.ERROR_SPATIAL_ENTITY_ID_INVALID_EXT: SpatialEntityIdInvalidEXTError,
+    Result.ERROR_SPATIAL_BUFFER_ID_INVALID_EXT: SpatialBufferIdInvalidEXTError,
+    Result.ERROR_SPATIAL_COMPONENT_UNSUPPORTED_FOR_CAPABILITY_EXT: SpatialComponentUnsupportedForCapabilityEXTError,
+    Result.ERROR_SPATIAL_CAPABILITY_CONFIGURATION_INVALID_EXT: SpatialCapabilityConfigurationInvalidEXTError,
+    Result.ERROR_SPATIAL_COMPONENT_NOT_ENABLED_EXT: SpatialComponentNotEnabledEXTError,
+    Result.ERROR_SPATIAL_PERSISTENCE_SCOPE_UNSUPPORTED_EXT: SpatialPersistenceScopeUnsupportedEXTError,
+    Result.ERROR_SPATIAL_PERSISTENCE_SCOPE_INCOMPATIBLE_EXT: SpatialPersistenceScopeIncompatibleEXTError,
+    Result.ERROR_EXTENSION_DEPENDENCY_NOT_ENABLED_KHR: ExtensionDependencyNotEnabledKHRError,
+    Result.ERROR_PERMISSION_INSUFFICIENT_KHR: PermissionInsufficientKHRError,
 }
 
 
@@ -1214,20 +1781,33 @@ __all__ = [
     "ActionTypeMismatchError",
     "ActionsetNotAttachedError",
     "ActionsetsAlreadyAttachedError",
+    "AnchorAlreadyPersistedANDROIDError",
+    "AnchorIdNotFoundANDROIDError",
+    "AnchorNotOwnedByCallerANDROIDError",
+    "AnchorNotSupportedForEntityBDError",
+    "AnchorNotTrackingANDROIDError",
     "AndroidThreadSettingsFailureKHRError",
     "AndroidThreadSettingsIdInvalidKHRError",
     "ApiLayerNotPresentError",
     "ApiVersionUnsupportedError",
     "CallOrderInvalidError",
+    "ColocationDiscoveryAlreadyAdvertisingMETA",
+    "ColocationDiscoveryAlreadyDiscoveringMETA",
+    "ColocationDiscoveryNetworkFailedMETAError",
+    "ColocationDiscoveryNoDiscoveryMethodMETAError",
     "ColorSpaceUnsupportedFBError",
     "ComputeNewSceneNotCompletedMSFTError",
     "ControllerModelKeyInvalidMSFTError",
     "CreateSpatialAnchorFailedMSFTError",
     "DisplayRefreshRateUnsupportedFBError",
     "EnvironmentBlendModeUnsupportedError",
+    "EnvironmentDepthNotAvailableMETA",
     "ErrorResult",
     "EventUnavailable",
+    "ExtensionDependencyNotEnabledError",
+    "ExtensionDependencyNotEnabledKHRError",
     "ExtensionNotPresentError",
+    "FacialExpressionPermissionDeniedMLError",
     "FeatureAlreadyCreatedPassthroughFBError",
     "FeatureRequiredPassthroughFBError",
     "FeatureUnsupportedError",
@@ -1237,9 +1817,12 @@ __all__ = [
     "FormFactorUnsupportedError",
     "FrameDiscarded",
     "FunctionUnsupportedError",
+    "FutureInvalidEXTError",
+    "FuturePendingEXTError",
     "GraphicsDeviceInvalidError",
     "GraphicsRequirementsCallMissingError",
     "HandleInvalidError",
+    "HintAlreadySetQCOMError",
     "IndexOutOfRangeError",
     "InitializationFailedError",
     "InstanceLostError",
@@ -1247,31 +1830,56 @@ __all__ = [
     "LayerInvalidError",
     "LayerLimitExceededError",
     "LimitReachedError",
+    "LocalizationMapAlreadyExistsMLError",
+    "LocalizationMapCannotExportCloudMapMLError",
+    "LocalizationMapFailMLError",
+    "LocalizationMapImportExportPermissionDeniedMLError",
+    "LocalizationMapIncompatibleMLError",
+    "LocalizationMapPermissionDeniedMLError",
+    "LocalizationMapUnavailableMLError",
     "LocalizedNameDuplicatedError",
     "LocalizedNameInvalidError",
+    "MarkerDetectorInvalidCreateInfoMLError",
+    "MarkerDetectorInvalidDataQueryMLError",
+    "MarkerDetectorLocateFailedMLError",
+    "MarkerDetectorPermissionDeniedMLError",
     "MarkerIdInvalidVarjoError",
+    "MarkerInvalidMLError",
     "MarkerNotTrackedVarjoError",
+    "MismatchingTrackableTypeANDROIDError",
     "NameDuplicatedError",
     "NameInvalidError",
+    "NotAnAnchorHTCError",
+    "NotInteractionRenderModelEXTError",
     "NotPermittedPassthroughFBError",
     "OutOfMemoryError",
+    "PassthroughColorLutBufferSizeMismatchMETAError",
     "PathCountExceededError",
     "PathFormatInvalidError",
     "PathInvalidError",
     "PathUnsupportedError",
+    "PermissionInsufficientError",
+    "PermissionInsufficientKHRError",
+    "PersistedDataNotReadyANDROIDError",
+    "PlaneDetectionPermissionDeniedEXTError",
     "PoseInvalidError",
     "QualifiedSuccessResult",
     "ReferenceSpaceUnsupportedError",
+    "RenderModelAssetUnavailableEXTError",
+    "RenderModelGltfExtensionRequiredEXTError",
+    "RenderModelIdInvalidEXTError",
     "RenderModelKeyInvalidFBError",
     "RenderModelUnavailableFB",
     "ReprojectionModeUnsupportedMSFTError",
     "ResultException",
     "RuntimeFailureError",
     "RuntimeUnavailableError",
+    "SceneCaptureFailureBDError",
     "SceneComponentIdInvalidMSFTError",
     "SceneComponentTypeMismatchMSFTError",
     "SceneComputeConsistencyMismatchMSFTError",
     "SceneComputeFeatureIncompatibleMSFTError",
+    "SceneMarkerDataNotStringMSFT",
     "SceneMeshBufferIdInvalidMSFTError",
     "SecondaryViewConfigurationTypeNotEnabledMSFTError",
     "SessionLossPending",
@@ -1283,22 +1891,62 @@ __all__ = [
     "SessionRunningError",
     "SizeInsufficientError",
     "SpaceBoundsUnavailable",
+    "SpaceCloudStorageDisabledFBError",
     "SpaceComponentNotEnabledFBError",
     "SpaceComponentNotSupportedFBError",
     "SpaceComponentStatusAlreadySetFBError",
     "SpaceComponentStatusPendingFBError",
+    "SpaceGroupNotFoundMETAError",
+    "SpaceInsufficientResourcesMETAError",
+    "SpaceInsufficientViewMETAError",
+    "SpaceLocalizationFailedFBError",
+    "SpaceMappingInsufficientFBError",
+    "SpaceNetworkRequestFailedFBError",
+    "SpaceNetworkTimeoutFBError",
+    "SpaceNotLocatableEXTError",
+    "SpacePermissionInsufficientMETAError",
+    "SpaceRateLimitedMETAError",
+    "SpaceStorageAtCapacityMETAError",
+    "SpaceTooBrightMETAError",
+    "SpaceTooDarkMETAError",
     "SpatialAnchorNameInvalidMSFTError",
     "SpatialAnchorNameNotFoundMSFTError",
+    "SpatialAnchorNotFoundBDError",
+    "SpatialAnchorSharingAuthenticationFailureBDError",
+    "SpatialAnchorSharingLocalizationFailBDError",
+    "SpatialAnchorSharingMapInsufficientBDError",
+    "SpatialAnchorSharingNetworkFailureBDError",
+    "SpatialAnchorSharingNetworkTimeoutBDError",
+    "SpatialAnchorsAnchorNotFoundMLError",
+    "SpatialAnchorsNotLocalizedMLError",
+    "SpatialAnchorsOutOfMapBoundsMLError",
+    "SpatialAnchorsPermissionDeniedMLError",
+    "SpatialAnchorsSpaceNotLocatableMLError",
+    "SpatialBufferIdInvalidEXTError",
+    "SpatialCapabilityConfigurationInvalidEXTError",
+    "SpatialCapabilityUnsupportedEXTError",
+    "SpatialComponentNotEnabledEXTError",
+    "SpatialComponentUnsupportedForCapabilityEXTError",
+    "SpatialEntityIdInvalidBDError",
+    "SpatialEntityIdInvalidEXTError",
+    "SpatialPersistenceScopeIncompatibleEXTError",
+    "SpatialPersistenceScopeUnsupportedEXTError",
+    "SpatialSensingServiceUnavailableBDError",
     "Success",
     "SwapchainFormatUnsupportedError",
     "SwapchainRectInvalidError",
     "SystemInvalidError",
+    "SystemNotificationIncompatibleSkuMLError",
+    "SystemNotificationPermissionDeniedMLError",
     "TimeInvalidError",
     "TimeoutExpired",
+    "TrackableTypeNotSupportedANDROIDError",
     "UnexpectedStatePassthroughFBError",
     "UnknownPassthroughFBError",
     "ValidationFailureError",
     "ViewConfigurationTypeUnsupportedError",
+    "WorldMeshDetectorPermissionDeniedMLError",
+    "WorldMeshDetectorSpaceNotLocatableMLError",
     "XrException",
     "check_result",
 ]
